@@ -17,10 +17,7 @@ limitations under the License.
 package main
 
 import (
-	"encoding/json"
 	"fmt"
-	"io"
-	"net/http"
 	"strings"
 
 	"k8s.io/klog/v2"
@@ -28,10 +25,6 @@ import (
 	"k8s.io/minikube/hack/update"
 )
 
-const (
-	dockerHubUbuntuBaseURL = "https://hub.docker.com/v2/repositories/library/ubuntu/tags"
-)
-
 var (
 	schema = map[string]update.Item{
 		"deploy/kicbase/Dockerfile": {
@@ -47,48 +40,25 @@ type Data struct {
 	LatestVersion string
 }
 
-// Response is used to unmarshal the response from Docker Hub
-type Response struct {
-	Results []struct {
-		Name string `json:"name"`
-	}
-}
-
-func getLatestVersion() (string, error) {
-	resp, err := http.Get(dockerHubUbuntuBaseURL)
-	if err != nil {
-		return "", fmt.Errorf("unable to get Ubuntu jammy's latest version: %v", err)
-	}
-	defer resp.Body.Close()
-
-	body, err := io.ReadAll(resp.Body)
-	if err != nil {
-		return "", fmt.Errorf("unable to read HTTP response from Docker Hub: %v", err)
-	}
-
-	var content Response
-	err = json.Unmarshal(body, &content)
-	if err != nil {
-		return "", fmt.Errorf("unable to unmarshal response from Docker Hub: %v", err)
-	}
-
-	for _, i := range content.Results {
-		if strings.Contains(i.Name, "jammy-") {
-			return i.Name, nil
+func latestJammyTag(tags []string) (string, error) {
+	for _, tag := range tags {
+		if strings.Contains(tag, "jammy-") {
+			return tag, nil
 		}
 	}
-
-	return "", fmt.Errorf("response from Docker Hub does not contain a latest jammy image")
+	return "", fmt.Errorf("no tag found that matches: jammy-")
 }
 
 func main() {
-	// get Ubuntu Jammy latest version
-	latest, err := getLatestVersion()
+	tags, err := update.ImageTagsFromDockerHub("library/ubuntu")
 	if err != nil {
-		klog.Fatalf("Unable to find latest ubuntu:jammy version: %v\n", err)
+		klog.Fatal(err)
 	}
-	data := Data{LatestVersion: fmt.Sprintf("ubuntu:%s", latest)}
-	klog.Infof("Ubuntu jammy latest version: %s", latest)
+	jammyTag, err := latestJammyTag(tags)
+	if err != nil {
+		klog.Fatal(err)
+	}
+	data := Data{LatestVersion: fmt.Sprintf("ubuntu:%s", jammyTag)}
 
 	update.Apply(schema, data)
 }
