@@ -21,6 +21,19 @@ package constants
 // ValidKubernetesVersions is a list of Kubernetes versions in order from newest to oldest
 // This is used when outputting Kubernetes versions and to select the latest patch version when unspecified
 var ValidKubernetesVersions = []string{
+	"v1.33.1",
+	"v1.33.0",
+	"v1.33.0-rc.1",
+	"v1.33.0-rc.0",
+	"v1.33.0-beta.0",
+	"v1.33.0-alpha.3",
+	"v1.33.0-alpha.2",
+	"v1.33.0-alpha.1",
+	"v1.32.5",
+	"v1.32.4",
+	"v1.32.3",
+	"v1.32.2",
+	"v1.32.1",
 	"v1.32.0",
 	"v1.32.0-rc.2",
 	"v1.32.0-rc.1",
@@ -29,6 +42,11 @@ var ValidKubernetesVersions = []string{
 	"v1.32.0-alpha.3",
 	"v1.32.0-alpha.2",
 	"v1.32.0-alpha.1",
+	"v1.31.9",
+	"v1.31.8",
+	"v1.31.7",
+	"v1.31.6",
+	"v1.31.5",
 	"v1.31.4",
 	"v1.31.3",
 	"v1.31.2",
@@ -40,6 +58,11 @@ var ValidKubernetesVersions = []string{
 	"v1.31.0-alpha.3",
 	"v1.31.0-alpha.2",
 	"v1.31.0-alpha.1",
+	"v1.30.13",
+	"v1.30.12",
+	"v1.30.11",
+	"v1.30.10",
+	"v1.30.9",
 	"v1.30.8",
 	"v1.30.7",
 	"v1.30.6",
@@ -56,6 +79,9 @@ var ValidKubernetesVersions = []string{
 	"v1.30.0-alpha.3",
 	"v1.30.0-alpha.2",
 	"v1.30.0-alpha.1",
+	"v1.29.15",
+	"v1.29.14",
+	"v1.29.13",
 	"v1.29.12",
 	"v1.29.11",
 	"v1.29.10",
