@@ -41,6 +41,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/image"
 	"k8s.io/minikube/pkg/minikube/style"
 	"k8s.io/minikube/pkg/minikube/sysinit"
+	"k8s.io/minikube/pkg/util/retry"
 )
 
 // KubernetesContainerPrefix is the prefix of each Kubernetes container
@@ -167,6 +168,7 @@ func (r *Docker) Enable(disOthers bool, cgroupDriver string, inUserNamespace boo
 		return err
 	}
 
+	_ = r.Init.ResetFailed("docker")
 	if err := r.Init.Restart("docker"); err != nil {
 		return err
 	}
@@ -197,10 +199,20 @@ func (r *Docker) Enable(disOthers bool, cgroupDriver string, inUserNamespace boo
 			return err
 		}
 
-		// try to restart service if stopped, intentionally continue on any error
-		if !r.Init.Active(service) {
-			_ = r.Init.Restart(service)
-		}
+		_ = r.Init.ResetFailed(service)
+		_ = r.Init.Restart(service)
+		// try to restart service if stopped, restart until it works
+		retry.Expo(
+			func() error {
+				if !r.Init.Active(service) {
+					r.Init.ResetFailed(service)
+					r.Init.Restart(service)
+					return fmt.Errorf("cri-docker not running")
+				}
+				return nil
+			},
+			1*time.Second, time.Minute, 5,
+		)
 	}
 
 	return nil
@@ -208,6 +220,7 @@ func (r *Docker) Enable(disOthers bool, cgroupDriver string, inUserNamespace boo
 
 // Restart restarts Docker on a host
 func (r *Docker) Restart() error {
+	_ = r.Init.ResetFailed("docker")
 	return r.Init.Restart("docker")
 }
 
