@@ -32,22 +32,27 @@ import (
 	"github.com/pkg/errors"
 	"github.com/spf13/viper"
 	core "k8s.io/api/core/v1"
+	discoveryv1 "k8s.io/api/discovery/v1"
 	meta "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
+	corev1 "k8s.io/client-go/applyconfigurations/core/v1"
+	discoveryv1ac "k8s.io/client-go/applyconfigurations/discovery/v1"
+	"k8s.io/client-go/gentype"
 	typed_core "k8s.io/client-go/kubernetes/typed/core/v1"
 	"k8s.io/client-go/kubernetes/typed/core/v1/fake"
+	typed_discovery "k8s.io/client-go/kubernetes/typed/discovery/v1"
+	"k8s.io/client-go/rest"
 	testing_fake "k8s.io/client-go/testing"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/constants"
 	"k8s.io/minikube/pkg/minikube/tests"
 )
 
-// Mock Kubernetes client getter - NOT THREAD SAFE
+// MockClientGetter is a mock Kubernetes client getter - NOT THREAD SAFE
 type MockClientGetter struct {
-	servicesMap  map[string]typed_core.ServiceInterface
-	endpointsMap map[string]typed_core.EndpointsInterface
-	secretsMap   map[string]typed_core.SecretInterface
-	Fake         fake.FakeCoreV1
+	servicesMap      map[string]typed_core.ServiceInterface
+	endpointSliceMap map[string]typed_discovery.EndpointSliceInterface
+	secretsMap       map[string]typed_core.SecretInterface
 }
 
 // Force GetCoreClient to fail
@@ -58,185 +63,272 @@ func (m *MockClientGetter) GetCoreClient(string) (typed_core.CoreV1Interface, er
 		return nil, fmt.Errorf("test Error - Mocked Get")
 	}
 	return &MockCoreClient{
-		servicesMap:  m.servicesMap,
-		endpointsMap: m.endpointsMap,
-		secretsMap:   m.secretsMap}, nil
-}
-
-func (m *MockCoreClient) Secrets(_ string) typed_core.SecretInterface {
-	return &fake.FakeSecrets{Fake: &fake.FakeCoreV1{Fake: &testing_fake.Fake{}}}
-}
-
-func (m *MockCoreClient) Services(namespace string) typed_core.ServiceInterface {
-	return m.servicesMap[namespace]
+		FakeCoreV1:       fake.FakeCoreV1{Fake: &testing_fake.Fake{}},
+		servicesMap:      m.servicesMap,
+		endpointSliceMap: m.endpointSliceMap,
+		secretsMap:       m.secretsMap,
+	}, nil
 }
 
 // Mock Kubernetes client - NOT THREAD SAFE
 type MockCoreClient struct {
 	fake.FakeCoreV1
-	servicesMap  map[string]typed_core.ServiceInterface
-	endpointsMap map[string]typed_core.EndpointsInterface
-	secretsMap   map[string]typed_core.SecretInterface
+	servicesMap      map[string]typed_core.ServiceInterface
+	endpointSliceMap map[string]typed_discovery.EndpointSliceInterface
+	secretsMap       map[string]typed_core.SecretInterface
+}
+
+func (m *MockCoreClient) Secrets(namespace string) typed_core.SecretInterface {
+	return m.secretsMap[namespace]
+}
+
+func (m *MockCoreClient) Services(namespace string) typed_core.ServiceInterface {
+	svc := m.servicesMap[namespace]
+	if mockSvc, ok := svc.(*MockServiceInterface); ok && mockSvc.Fake == nil {
+		mockSvc.Fake = &testing_fake.Fake{}
+	}
+	return svc
+}
+
+func (m *MockCoreClient) DiscoveryV1() typed_discovery.DiscoveryV1Interface {
+	return &MockDiscoveryV1Interface{
+		endpointSliceMap: m.endpointSliceMap,
+	}
+}
+
+type MockDiscoveryV1Interface struct {
+	endpointSliceMap map[string]typed_discovery.EndpointSliceInterface
+}
+
+func (m *MockDiscoveryV1Interface) RESTClient() rest.Interface {
+	return nil
+}
+
+func (m *MockDiscoveryV1Interface) EndpointSlices(namespace string) typed_discovery.EndpointSliceInterface {
+	return m.endpointSliceMap[namespace]
+}
+
+type MockEndpointSliceInterface struct {
+	*gentype.FakeClientWithListAndApply[*discoveryv1.EndpointSlice, *discoveryv1.EndpointSliceList, *discoveryv1ac.EndpointSliceApplyConfiguration]
+	Fake          *testing_fake.Fake
+	EndpointSlice *discoveryv1.EndpointSlice
+}
+
+func (s *MockServiceInterface) ProxyGet(scheme, name, port, path string, params map[string]string) rest.ResponseWrapper {
+	return s.Fake.InvokesProxy(
+		testing_fake.NewProxyGetAction(core.SchemeGroupVersion.WithResource("services"), s.namespace, scheme, name, port, path, params),
+	)
+}
+
+type MockServiceInterface struct {
+	*gentype.FakeClientWithListAndApply[*core.Service, *core.ServiceList, *corev1.ServiceApplyConfiguration]
+	Fake        *testing_fake.Fake
+	ServiceList *core.ServiceList
+	namespace   string
+}
+
+type MockSecretInterface struct {
+	*gentype.FakeClientWithListAndApply[*core.Secret, *core.SecretList, *corev1.SecretApplyConfiguration]
+	Fake        *testing_fake.Fake
+	SecretsList *core.SecretList
 }
 
 var secretsNamespaces = map[string]typed_core.SecretInterface{
-	"default": defaultNamespaceSecretsInterface,
-}
-
-var defaultNamespaceSecretsInterface = &MockSecretInterface{
-	SecretsList: &core.SecretList{
-		Items: []core.Secret{
-			{},
+	"default": &MockSecretInterface{
+		FakeClientWithListAndApply: gentype.NewFakeClientWithListAndApply[*core.Secret, *core.SecretList, *corev1.SecretApplyConfiguration](
+			&testing_fake.Fake{},
+			"default",
+			core.SchemeGroupVersion.WithResource("secrets"),
+			core.SchemeGroupVersion.WithKind("Secret"),
+			func() *core.Secret { return &core.Secret{} },
+			func() *core.SecretList { return &core.SecretList{} },
+			func(dst, src *core.SecretList) { dst.ListMeta = src.ListMeta },
+			func(list *core.SecretList) []*core.Secret { return gentype.ToPointerSlice(list.Items) },
+			func(list *core.SecretList, items []*core.Secret) { list.Items = gentype.FromPointerSlice(items) },
+		),
+		Fake: &testing_fake.Fake{},
+		SecretsList: &core.SecretList{
+			Items: []core.Secret{},
+		},
+	},
+	"foo": &MockSecretInterface{
+		FakeClientWithListAndApply: gentype.NewFakeClientWithListAndApply[*core.Secret, *core.SecretList, *corev1.SecretApplyConfiguration](
+			&testing_fake.Fake{},
+			"foo",
+			core.SchemeGroupVersion.WithResource("secrets"),
+			core.SchemeGroupVersion.WithKind("Secret"),
+			func() *core.Secret { return &core.Secret{} },
+			func() *core.SecretList { return &core.SecretList{} },
+			func(dst, src *core.SecretList) { dst.ListMeta = src.ListMeta },
+			func(list *core.SecretList) []*core.Secret { return gentype.ToPointerSlice(list.Items) },
+			func(list *core.SecretList, items []*core.Secret) { list.Items = gentype.FromPointerSlice(items) },
+		),
+		Fake: &testing_fake.Fake{},
+		SecretsList: &core.SecretList{
+			Items: []core.Secret{},
 		},
 	},
 }
 
 var serviceNamespaces = map[string]typed_core.ServiceInterface{
-	"default": defaultNamespaceServiceInterface,
+	"default": &MockServiceInterface{
+		FakeClientWithListAndApply: gentype.NewFakeClientWithListAndApply[*core.Service, *core.ServiceList, *corev1.ServiceApplyConfiguration](
+			&testing_fake.Fake{},
+			"default",
+			core.SchemeGroupVersion.WithResource("services"),
+			core.SchemeGroupVersion.WithKind("Service"),
+			func() *core.Service { return &core.Service{} },
+			func() *core.ServiceList { return &core.ServiceList{} },
+			func(dst, src *core.ServiceList) { dst.ListMeta = src.ListMeta },
+			func(list *core.ServiceList) []*core.Service { return gentype.ToPointerSlice(list.Items) },
+			func(list *core.ServiceList, items []*core.Service) { list.Items = gentype.FromPointerSlice(items) },
+		),
+		Fake:      &testing_fake.Fake{},
+		namespace: "default",
+		ServiceList: &core.ServiceList{
+			Items: []core.Service{
+
+				{
+					ObjectMeta: meta.ObjectMeta{
+						Name:      "mock-dashboard",
+						Namespace: "default",
+						Labels:    map[string]string{"mock": "mock"},
+					},
+					Spec: core.ServiceSpec{
+						Ports: []core.ServicePort{
+							{
+								Name:     "port1",
+								NodePort: int32(1111),
+								Port:     int32(11111),
+								TargetPort: intstr.IntOrString{
+									IntVal: int32(11111),
+								},
+							},
+							{
+								Name:     "port2",
+								NodePort: int32(2222),
+								Port:     int32(22222),
+								TargetPort: intstr.IntOrString{
+									IntVal: int32(22222),
+								},
+							},
+						},
+					},
+				},
+				{
+					ObjectMeta: meta.ObjectMeta{
+						Name:      "mock-dashboard-no-ports",
+						Namespace: "default",
+						Labels:    map[string]string{"mock": "mock"},
+					},
+					Spec: core.ServiceSpec{
+						Ports: []core.ServicePort{},
+					},
+				},
+			},
+		},
+	},
 }
 
 var serviceNamespaceOther = map[string]typed_core.ServiceInterface{
-	"default": nondefaultNamespaceServiceInterface,
-}
-
-var nondefaultNamespaceServiceInterface = &MockServiceInterface{
-	ServiceList: &core.ServiceList{
-		Items: []core.Service{
-			{
-				ObjectMeta: meta.ObjectMeta{
-					Name:      "non-namespace-dashboard-no-ports",
-					Namespace: "cannot_be_found_namespace",
-					Labels:    map[string]string{"mock": "mock"},
-				},
-				Spec: core.ServiceSpec{
-					Ports: []core.ServicePort{},
-				},
-			},
-		},
-	},
-}
-
-var defaultNamespaceServiceInterface = &MockServiceInterface{
-	ServiceList: &core.ServiceList{
-		Items: []core.Service{
-			{
-				ObjectMeta: meta.ObjectMeta{
-					Name:      "mock-dashboard",
-					Namespace: "default",
-					Labels:    map[string]string{"mock": "mock"},
-				},
-				Spec: core.ServiceSpec{
-					Ports: []core.ServicePort{
-						{
-							Name:     "port1",
-							NodePort: int32(1111),
-							Port:     int32(11111),
-							TargetPort: intstr.IntOrString{
-								IntVal: int32(11111),
-							},
-						},
-						{
-							Name:     "port2",
-							NodePort: int32(2222),
-							Port:     int32(22222),
-							TargetPort: intstr.IntOrString{
-								IntVal: int32(22222),
-							},
-						},
+	"default": &MockServiceInterface{
+		FakeClientWithListAndApply: gentype.NewFakeClientWithListAndApply[*core.Service, *core.ServiceList, *corev1.ServiceApplyConfiguration](
+			&testing_fake.Fake{},
+			"default",
+			core.SchemeGroupVersion.WithResource("services"),
+			core.SchemeGroupVersion.WithKind("Service"),
+			func() *core.Service { return &core.Service{} },
+			func() *core.ServiceList { return &core.ServiceList{} },
+			func(dst, src *core.ServiceList) { dst.ListMeta = src.ListMeta },
+			func(list *core.ServiceList) []*core.Service { return gentype.ToPointerSlice(list.Items) },
+			func(list *core.ServiceList, items []*core.Service) { list.Items = gentype.FromPointerSlice(items) },
+		),
+		Fake:      &testing_fake.Fake{},
+		namespace: "default",
+		ServiceList: &core.ServiceList{
+			Items: []core.Service{
+				{
+					ObjectMeta: meta.ObjectMeta{
+						Name:      "non-namespace-dashboard-no-ports",
+						Namespace: "cannot_be_found_namespace",
+						Labels:    map[string]string{"mock": "mock"},
+					},
+					Spec: core.ServiceSpec{
+						Ports: []core.ServicePort{},
 					},
 				},
 			},
-			{
-				ObjectMeta: meta.ObjectMeta{
-					Name:      "mock-dashboard-no-ports",
-					Namespace: "default",
-					Labels:    map[string]string{"mock": "mock"},
-				},
-				Spec: core.ServiceSpec{
-					Ports: []core.ServicePort{},
-				},
-			},
 		},
 	},
 }
 
-var endpointNamespaces = map[string]typed_core.EndpointsInterface{
-	"default": defaultNamespaceEndpointInterface,
-}
-
-var defaultNamespaceEndpointInterface = &MockEndpointsInterface{}
-
-func (m *MockCoreClient) Endpoints(namespace string) typed_core.EndpointsInterface {
-	return m.endpointsMap[namespace]
-}
-
-type MockEndpointsInterface struct {
-	fake.FakeEndpoints
-	Endpoints *core.Endpoints
-}
-
-var endpointMap = map[string]*core.Endpoints{
-	"no-subsets": {},
-	"not-ready": {
-		Subsets: []core.EndpointSubset{
-			{
-				Addresses: []core.EndpointAddress{},
-				NotReadyAddresses: []core.EndpointAddress{
-					{IP: "1.1.1.1"},
-					{IP: "2.2.2.2"},
-				},
+var endpointSliceNamespaces = map[string]typed_discovery.EndpointSliceInterface{
+	"default": &MockEndpointSliceInterface{
+		FakeClientWithListAndApply: gentype.NewFakeClientWithListAndApply[*discoveryv1.EndpointSlice, *discoveryv1.EndpointSliceList, *discoveryv1ac.EndpointSliceApplyConfiguration](
+			&testing_fake.Fake{},
+			"default",
+			discoveryv1.SchemeGroupVersion.WithResource("endpointslices"),
+			discoveryv1.SchemeGroupVersion.WithKind("EndpointSlice"),
+			func() *discoveryv1.EndpointSlice { return &discoveryv1.EndpointSlice{} },
+			func() *discoveryv1.EndpointSliceList { return &discoveryv1.EndpointSliceList{} },
+			func(dst, src *discoveryv1.EndpointSliceList) { dst.ListMeta = src.ListMeta },
+			func(list *discoveryv1.EndpointSliceList) []*discoveryv1.EndpointSlice {
+				return gentype.ToPointerSlice(list.Items)
 			},
-		},
-	},
-	"one-ready": {
-		Subsets: []core.EndpointSubset{
-			{
-				Addresses: []core.EndpointAddress{
-					{IP: "1.1.1.1"},
-				},
-				NotReadyAddresses: []core.EndpointAddress{
-					{IP: "2.2.2.2"},
-				},
+			func(list *discoveryv1.EndpointSliceList, items []*discoveryv1.EndpointSlice) {
+				list.Items = gentype.FromPointerSlice(items)
 			},
-		},
+		),
+		Fake: &testing_fake.Fake{},
 	},
+}
+
+var endpointSliceMap = map[string]*discoveryv1.EndpointSlice{
 	"mock-dashboard": {
-		Subsets: []core.EndpointSubset{
+		ObjectMeta: meta.ObjectMeta{
+			Name:      "mock-dashboard",
+			Namespace: "default",
+		},
+		Endpoints: []discoveryv1.Endpoint{
 			{
-				Ports: []core.EndpointPort{
-					{
-						Name: "port1",
-						Port: int32(11111),
-					},
-					{
-						Name: "port2",
-						Port: int32(22222),
-					},
+				Conditions: discoveryv1.EndpointConditions{
+					Ready: &[]bool{true}[0],
 				},
+				Addresses: []string{"1.1.1.1"},
 			},
 		},
+		Ports: []discoveryv1.EndpointPort{
+			{
+				Name: &[]string{"port1"}[0],
+				Port: &[]int32{11111}[0],
+			},
+			{
+				Name: &[]string{"port2"}[0],
+				Port: &[]int32{22222}[0],
+			},
+		},
+	},
+	"mock-dashboard-no-ports": {
+		ObjectMeta: meta.ObjectMeta{
+			Name:      "mock-dashboard-no-ports",
+			Namespace: "default",
+		},
 	},
 }
 
-func (e MockEndpointsInterface) Get(_ context.Context, name string, _ meta.GetOptions) (*core.Endpoints, error) {
-	endpoint, ok := endpointMap[name]
-	if !ok {
-		return nil, errors.New("Endpoint not found")
+func (e *MockEndpointSliceInterface) Get(_ context.Context, name string, _ meta.GetOptions) (*discoveryv1.EndpointSlice, error) {
+	if e.Fake == nil {
+		e.Fake = &testing_fake.Fake{}
 	}
-	return endpoint, nil
+
+	endpointSlice, ok := endpointSliceMap[name]
+	if !ok {
+		return nil, errors.New("EndpointSlice not found")
+	}
+	return endpointSlice, nil
 }
 
-type MockServiceInterface struct {
-	fake.FakeServices
-	ServiceList *core.ServiceList
-}
-
-type MockSecretInterface struct {
-	fake.FakeSecrets
-	SecretsList *core.SecretList
-}
-
-func (s MockServiceInterface) List(_ context.Context, opts meta.ListOptions) (*core.ServiceList, error) {
+func (s *MockServiceInterface) List(_ context.Context, opts meta.ListOptions) (*core.ServiceList, error) {
 	serviceList := &core.ServiceList{
 		Items: []core.Service{},
 	}
@@ -255,7 +347,7 @@ func (s MockServiceInterface) List(_ context.Context, opts meta.ListOptions) (*c
 	return s.ServiceList, nil
 }
 
-func (s MockServiceInterface) Get(_ context.Context, name string, _ meta.GetOptions) (*core.Service, error) {
+func (s *MockServiceInterface) Get(_ context.Context, name string, _ meta.GetOptions) (*core.Service, error) {
 	for _, svc := range s.ServiceList.Items {
 		if svc.ObjectMeta.Name == name {
 			return &svc, nil
@@ -265,11 +357,41 @@ func (s MockServiceInterface) Get(_ context.Context, name string, _ meta.GetOpti
 	return nil, errors.New("Service not found")
 }
 
-func (s MockServiceInterface) Create(_ context.Context, service *core.Service, _ meta.CreateOptions) (*core.Service, error) {
+func (s *MockServiceInterface) Create(_ context.Context, service *core.Service, _ meta.CreateOptions) (*core.Service, error) {
 	s.ServiceList.Items = append(s.ServiceList.Items, *service)
 	return service, nil
 }
 
+func initializeMockObjects() {
+	// Initialize Fake field in serviceNamespaces
+	for _, svc := range serviceNamespaces {
+		if mockSvc, ok := svc.(*MockServiceInterface); ok && mockSvc.Fake == nil {
+			mockSvc.Fake = &testing_fake.Fake{}
+		}
+	}
+
+	// Initialize Fake field in serviceNamespaceOther
+	for _, svc := range serviceNamespaceOther {
+		if mockSvc, ok := svc.(*MockServiceInterface); ok && mockSvc.Fake == nil {
+			mockSvc.Fake = &testing_fake.Fake{}
+		}
+	}
+
+	// Initialize Fake field in endpointSliceNamespaces
+	for _, es := range endpointSliceNamespaces {
+		if mockES, ok := es.(*MockEndpointSliceInterface); ok && mockES.Fake == nil {
+			mockES.Fake = &testing_fake.Fake{}
+		}
+	}
+
+	// Initialize Fake field in secretsNamespaces
+	for _, secret := range secretsNamespaces {
+		if mockSecret, ok := secret.(*MockSecretInterface); ok && mockSecret.Fake == nil {
+			mockSecret.Fake = &testing_fake.Fake{}
+		}
+	}
+}
+
 func TestGetServiceListFromServicesByLabel(t *testing.T) {
 	serviceList := &core.ServiceList{
 		Items: []core.Service{
@@ -295,11 +417,17 @@ func TestGetServiceListFromServicesByLabel(t *testing.T) {
 }
 
 func TestPrintURLsForService(t *testing.T) {
+	// Initialize all mock objects before the test
+	initializeMockObjects()
+
 	defaultTemplate := template.Must(template.New("svc-template").Parse("http://{{.IP}}:{{.Port}}"))
+
 	client := &MockCoreClient{
-		servicesMap:  serviceNamespaces,
-		endpointsMap: endpointNamespaces,
+		FakeCoreV1:       fake.FakeCoreV1{Fake: &testing_fake.Fake{}},
+		servicesMap:      serviceNamespaces,
+		endpointSliceMap: endpointSliceNamespaces,
 	}
+
 	var tests = []struct {
 		description    string
 		serviceName    string
@@ -360,7 +488,6 @@ func TestPrintURLsForService(t *testing.T) {
 }
 
 func TestOptionallyHttpsFormattedUrlString(t *testing.T) {
-
 	var tests = []struct {
 		description                     string
 		bareURLString                   string
@@ -417,6 +544,9 @@ func TestOptionallyHttpsFormattedUrlString(t *testing.T) {
 }
 
 func TestGetServiceURLs(t *testing.T) {
+	// Initialize all mock objects before the test
+	initializeMockObjects()
+
 	defaultAPI := &tests.MockAPI{
 		FakeStore: tests.FakeStore{
 			Hosts: map[string]*host.Host{
@@ -472,8 +602,8 @@ func TestGetServiceURLs(t *testing.T) {
 		test := test
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
 			}
 			urls, err := GetServiceURLs(test.api, "minikube", test.namespace, defaultTemplate)
 			if err != nil && !test.err {
@@ -490,6 +620,9 @@ func TestGetServiceURLs(t *testing.T) {
 }
 
 func TestGetServiceURLsForService(t *testing.T) {
+	// Initialize all mock objects before the test
+	initializeMockObjects()
+
 	defaultAPI := &tests.MockAPI{
 		FakeStore: tests.FakeStore{
 			Hosts: map[string]*host.Host{
@@ -540,8 +673,8 @@ func TestGetServiceURLsForService(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
 			}
 			svcURL, err := GetServiceURLsForService(test.api, "minikube", test.namespace, test.service, defaultTemplate)
 			if err != nil && !test.err {
@@ -677,9 +810,9 @@ func TestGetServiceListByLabel(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
-				secretsMap:   secretsNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
+				secretsMap:       secretsNamespaces,
 			}
 			getCoreClientFail = test.failedGetClient
 			svcs, err := GetServiceListByLabel("minikube", test.ns, test.name, test.label)
@@ -727,9 +860,9 @@ func TestCheckService(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
-				secretsMap:   secretsNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
+				secretsMap:       secretsNamespaces,
 			}
 			getCoreClientFail = test.failedGetClient
 			err := CheckService("minikube", test.ns, test.name)
@@ -766,9 +899,9 @@ func TestDeleteSecret(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
-				secretsMap:   secretsNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
+				secretsMap:       secretsNamespaces,
 			}
 			getCoreClientFail = test.failedGetClient
 			err := DeleteSecret("minikube", test.ns, test.name)
@@ -805,9 +938,9 @@ func TestCreateSecret(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
-				secretsMap:   secretsNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
+				secretsMap:       secretsNamespaces,
 			}
 			getCoreClientFail = test.failedGetClient
 			err := CreateSecret("minikube", test.ns, test.name, map[string]string{"ns": "secret"}, map[string]string{"ns": "baz"})
@@ -822,6 +955,9 @@ func TestCreateSecret(t *testing.T) {
 }
 
 func TestWaitAndMaybeOpenService(t *testing.T) {
+	// Initialize all mock objects before the test
+	initializeMockObjects()
+
 	defaultAPI := &tests.MockAPI{
 		FakeStore: tests.FakeStore{
 			Hosts: map[string]*host.Host{
@@ -844,15 +980,6 @@ func TestWaitAndMaybeOpenService(t *testing.T) {
 		https       bool
 		err         bool
 	}{
-		/*	{
-			description: "no host",
-			api: &tests.mockapi{
-				fakestore: tests.fakestore{
-					hosts: make(map[string]*host.host),
-				},
-			},
-			err: true,
-		}, */
 		{
 			description: "correctly return serviceURLs, https, no url mode",
 			namespace:   "default",
@@ -915,15 +1042,18 @@ func TestWaitAndMaybeOpenService(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaces,
-				endpointsMap: endpointNamespaces,
+				servicesMap:      serviceNamespaces,
+				endpointSliceMap: endpointSliceNamespaces,
 			}
 
 			go func() {
-				// wait for the delayed mock service to be created
 				time.Sleep(2 * time.Second)
-
-				_, _ = serviceNamespaces[test.namespace].Create(context.Background(), &core.Service{
+				// Make sure the fake field is initialized for the service interface
+				svcInterface := serviceNamespaces[test.namespace]
+				if mockSvc, ok := svcInterface.(*MockServiceInterface); ok && mockSvc.Fake == nil {
+					mockSvc.Fake = &testing_fake.Fake{}
+				}
+				_, _ = svcInterface.Create(context.Background(), &core.Service{
 					ObjectMeta: meta.ObjectMeta{
 						Name:      "mock-dashboard-delayed",
 						Namespace: "default",
@@ -954,24 +1084,22 @@ func TestWaitAndMaybeOpenService(t *testing.T) {
 			}
 
 			if test.urlMode {
-				// check the size of the url slices
 				if len(urlList) != len(test.expected) {
 					t.Fatalf("WaitForService returned [%d] urls while expected is [%d] url", len(urlList), len(test.expected))
 				}
-
-				// check content of the expected url
 				for i, v := range test.expected {
 					if v != urlList[i] {
 						t.Fatalf("WaitForService returned [%s] urls while expected is [%s] url", urlList[i], v)
 					}
 				}
 			}
-
 		})
 	}
 }
 
 func TestWaitAndMaybeOpenServiceForNotDefaultNamspace(t *testing.T) {
+	initializeMockObjects()
+
 	defaultAPI := &tests.MockAPI{
 		FakeStore: tests.FakeStore{
 			Hosts: map[string]*host.Host{
@@ -1007,8 +1135,8 @@ func TestWaitAndMaybeOpenServiceForNotDefaultNamspace(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
 			K8s = &MockClientGetter{
-				servicesMap:  serviceNamespaceOther,
-				endpointsMap: endpointNamespaces,
+				servicesMap:      serviceNamespaceOther,
+				endpointSliceMap: endpointSliceNamespaces,
 			}
 			_, err := WaitForService(test.api, "minikube", test.namespace, test.service, defaultTemplate, test.urlMode, test.https, 1, 0)
 			if test.err && err == nil {
@@ -1017,7 +1145,6 @@ func TestWaitAndMaybeOpenServiceForNotDefaultNamspace(t *testing.T) {
 			if !test.err && err != nil {
 				t.Fatalf("WaitForService not expected to fail but got err: %v", err)
 			}
-
 		})
 	}
 }
